# -*- coding: utf-8 -*-

"""
mdnotes

This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

from mdnotes.api_helper import APIHelper
from mdnotes.configuration import Server
from mdnotes.controllers.base_controller import BaseController
from mdnotes.models.user import User


class UserController(BaseController):

    """A Controller to access Endpoints in the mdnotes API."""

    def __init__(self, config, call_back=None):
        super(UserController, self).__init__(config, call_back)

    def get_user(self):
        """Does a GET request to /api/user.

        TODO: type endpoint description here.

        Returns:
            User: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/api/user'
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.config.http_client.get(_query_url, headers=_headers)
        _response = self.execute_request(_request)
        self.validate_response(_response)

        decoded = APIHelper.json_deserialize(_response.text, User.from_dictionary)

        return decoded
